@@ -98,6 +98,8 @@ my %default_config = (
     history_height => 10,
 
     command             => q{},
+    command_pre         => q{},
+    command_post        => q{},
     hide_menu           => 0,
     max_host_menu_items => 30,
 
